developerscripttools.CountToolsScript
=====================================

.. abjad-lineage:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript

.. autoclass:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.alias
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.argument_parser
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.formatted_help
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.formatted_usage
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.formatted_version
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.long_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.program_name
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.scripting_group
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.short_description
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.storage_format
   :noindex:

.. autoattribute:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.version
   :noindex:

Methods
-------

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.process_args
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.setup_argument_parser
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__call__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__eq__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__ge__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__gt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__le__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__lt__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__ne__
   :noindex:

.. automethod:: abjad.tools.developerscripttools.CountToolsScript.CountToolsScript.CountToolsScript.__repr__
   :noindex:
